@@ -4,24 +4,23 @@ import librosa
 import librosa.display
 import argparse
 import audio_metadata
+import cv2
 
 
 class Conf:
     
-    def __init__(self,sampling_rate,duration):
+    def __init__(self,duration):
 
-        self.sampling_rate = sampling_rate
+        self.sampling_rate = 44100
         self.duration = duration + 1 # sec
-        self.hop_length = 347*duration  # to make time steps 128
-        self.fmin = 20
-        self.fmax = sampling_rate // 2
+        self.hop_length = int(self.sampling_rate * self.duration / 1000)
         self.n_mels = 128
-        self.n_fft = self.n_mels * 20
-        self.samples = sampling_rate * duration
+        self.n_fft = 2048
+        self.samples = self.sampling_rate * duration
 
 
 def get_audio_data(conf, pathname, trim_long_data):
-    audio_data, sr = librosa.load(pathname, sr=conf.sampling_rate)
+    audio_data, sr = librosa.load(pathname)
 
     if len(audio_data):
         audio_data, _ = librosa.effects.trim(audio_data)
@@ -44,10 +43,9 @@ def audio_to_melspectrogram(conf, audio):
                                                  n_mels=conf.n_mels,
                                                  hop_length=conf.hop_length,
                                                  n_fft=conf.n_fft,
-                                                 fmin=conf.fmin,
-                                                 fmax=conf.fmax)
-    spectrogram = librosa.power_to_db(spectrogram)
-    spectrogram = spectrogram.astype(np.float32)
+                                                 fmin=0.0,
+                                                fmax=None
+                                                 )
     return spectrogram
 
 
@@ -60,7 +58,7 @@ def read_as_melspectrogram(conf, pathname, trim_long_data):
 def rename_file(img_name):
     img_name = img_name.split("/")[-1]
     img_name = img_name.split(".")[0]
-    img_name += ".jpg"
+    img_name += ".png"
     return img_name
 
 
@@ -71,17 +69,24 @@ def save_image_from_sound(sound_path,show_image=False,output=""):
         filename = output
     else:
         filename = rename_file(sound_path)
-    wav_conf = Conf(int(info.streaminfo.sample_rate), int(info.streaminfo.duration))
+    wav_conf = Conf( int(info.streaminfo.duration))
     x = read_as_melspectrogram(
         wav_conf, sound_path, trim_long_data=False)
 
-    plt.imshow(x, interpolation='nearest')
-    # remove axis
-    plt.axis('off')
-    plt.savefig(filename, bbox_inches='tight', pad_inches=0)
     if show_image:
+        plt.figure(figsize=(12, 4))
+        librosa.display.specshow(x, sr=wav_conf.sampling_rate,
+                                 hop_length=wav_conf.hop_length, x_axis='time', y_axis='mel')
+        plt.colorbar(format='%+2.0f dB')
+        plt.title('Mel spectrogram')
+        plt.tight_layout()
         plt.show()
-    plt.close()
+
+
+    cv2.imwrite(filename, x)
+    return x
+
+sound_to_image = save_image_from_sound
 
 if __name__ == "__main__":
     parser = argparse.ArgumentParser()
